@@ -20,6 +20,40 @@ namespace binder {
 using namespace ost;
 using namespace std;
 
+
+bool Methods::scrKeydata(void)
+{
+	Line *line = getLine();
+	char buf[80];
+	Name *scr = getName();
+	ScriptImage *img = getImage();
+	const char *cp = NULL;
+
+	if(isAssociated())
+	{
+		redirect("connect::outgoing");
+		return false;
+	}
+
+	snprintf(buf, sizeof(buf), "%s.connect", scr->name);
+	cp = img->getLast(buf);
+	if(cp)
+	{
+		redirect(cp);
+		return false;
+	}
+
+
+	if(line->next)
+	{
+		advance();
+		return true;
+	}
+
+	redirect("connect::incoming");
+	return false;
+}	
+
 bool Methods::scrStart(void)
 {
 	ScriptImage **ip = getLocalImage(timeslot);
