@@ -105,9 +105,73 @@ BayonneBinder("ivrscript1")
 	addConfig("feature.conf");
 	addConfig("caller.conf");
 	addConfig("dialed.conf");
+	addConfig("local.conf");
 	addConfig("runlevel.conf");
 };
 
+Script::Name *Binder::getIncoming(ScriptImage *img, BayonneSession *s, Event *event)
+{
+	const char *cid, *did, *uid;
+	char buf[80];
+	Name *scr = NULL;
+
+	if(sla[0])
+	{
+		scr = img->getScript(sla);
+		if(scr)
+			return scr;
+	}
+	did = s->getSymbol("session.hostname");
+	if(did && !*did)
+		did = NULL;
+
+	if(did)
+	{
+		snprintf(buf, sizeof(buf), "dialed::%s", did);
+		scr = img->getScript(buf);
+		if(scr)		
+			return scr;
+	}
+
+	uid = getRegistryId(s->getSymbol("session.identity"));
+	cid = getRegistryId(s->getSymbol("session.caller"));
+
+	if(cid && !uid)
+	{
+		snprintf(buf, sizeof(buf), "caller::%s", cid);
+		scr = img->getScript(buf);
+		if(scr)
+			return scr;
+	}
+
+	if(uid)
+	{
+		snprintf(buf, sizeof(buf), "local::%s", uid);
+		scr = img->getScript(buf);
+		if(scr)
+			return scr;
+	}
+
+	did = getRegistryId(s->getSymbol("session.dialed"));
+	if(did && uid && !stricmp(did, uid))
+	{
+		scr = img->getScript("local::_self_");
+		if(scr)
+			return scr;
+	}
+
+	if(did)
+	{
+		snprintf(buf, sizeof(buf), "dialed::%s", did);
+		scr = img->getScript(buf);
+		if(scr)
+			return scr;
+	}
+
+	return BayonneBinder::getIncoming(img, s, event);
+}
+
+
 bool Binder::select(ScriptInterp *interp)
 {
         char buf[65]; 
