@@ -87,6 +87,21 @@ bool Methods::scrKeydata(void)
 {
 	Line *line = getLine();
 	const char *ext = getSymbol("session.identity");
+	const char *did = getSymbol("session.dialed");
+	const char *anon = getSymbol("session.anonymous");
+	char buf[80];
+	Name *scr = getName();
+	ScriptImage *img = getImage();
+	const char *cp = NULL;
+
+	if(anon && !*anon)
+		anon = NULL;
+
+	if(did && !*did)
+		did = NULL;
+
+	if(ext && !*ext)
+		ext = NULL;
 
 	if(isAssociated() && ext && *ext)
 	{
@@ -100,12 +115,48 @@ bool Methods::scrKeydata(void)
 		return false;
 	}
 
-	if(!line->next)
+	snprintf(buf, sizeof(buf), "%s.connect", scr->name);
+	cp = img->getLast(buf);
+	scr = NULL;
+	if(cp && strchr(cp, ':'))
+		scr = getScript(cp);
+	else if(cp)
 	{
-		redirect("connect::common");
-		return false;
+		snprintf(buf, sizeof(buf), "connect::%s", cp);
+		scr = getScript(buf);
+	}
+	if(scr)
+		goto branch;
+
+	if(line->next)
+		goto next;
+
+	if(did && anon)
+	{
+		snprintf(buf, sizeof(buf), "dialed::%s", did);
+		scr = getScript(buf);
 	}
 
+	if(anon && !scr)
+		scr = getScript("connect::anonymous");
+
+	if(ext && !scr)
+		scr = getScript("connect::extension");
+	
+    if(scr)
+    {
+branch:
+        clearStack();
+        frame[stack].script = scr;
+        frame[stack].line = frame[stack].first = scr->first;
+        frame[stack].mask = getMask();
+        return true;
+    }
+
+	redirect("connect::common");
+	return true;
+
+next:
 	advance();
 	return true;
 }	
