@@ -255,6 +255,24 @@ bool Bayonne::getUserdata(void)
 #endif
 }
 
+const char *Bayonne::getRegistryId(const char *id)
+{
+	const char *cp;
+
+	if(!id || !*id)
+		return NULL;
+
+	cp = strchr(id, '/');
+	if(cp)
+		return ++cp;
+
+	cp = strrchr(id, ':');
+	if(cp)
+		return ++cp;
+
+	return id;
+}
+
 void Bayonne::waitLoaded(void)
 {
 	while(!image_loaded)
@@ -1034,7 +1052,7 @@ void Bayonne::errlog(const char *level, const char *fmt, ...)
 		Bayonne::server->errlog(level, buffer);
 }
 	
-BayonneSession *Bayonne::startDialing(const char *dial, const char *name, const char *caller, const char *display, BayonneSession *parent)
+BayonneSession *Bayonne::startDialing(const char *dial, const char *name, const char *caller, const char *display, BayonneSession *parent, const char *manager)
 {
 	ScriptImage *img;
 	BayonneDriver *d = BayonneDriver::getTrunking();
@@ -1254,8 +1272,10 @@ start:
 	event.start.dialing = dial;
 	event.start.parent = parent;
 
-        session->setConst("session.caller", caller);
-        session->setConst("session.display", display);
+	if(manager)
+		session->setConst("session.manager", manager);
+	session->setConst("session.caller", caller);
+	session->setConst("session.display", display);
 
         if(!session->postEvent(&event))
         {
