@@ -995,6 +995,10 @@ public:
 	 */	
 	static void allocate(timeslot_t timeslots, ScriptCommand *pointer = NULL, timeslot_t overdraft = 0);
 
+	static const char *getRegistryId(const char *id);
+
+	static BayonneDriver *getDriverTag(const char *id);
+
 	static Audio::Encoding getEncoding(const char *cp);
 
 	/**
@@ -1083,7 +1087,8 @@ public:
 	 * @param parent to join to.
 	 */
 	static BayonneSession *startDialing(const char *dial, 
-		const char *name, const char *caller, const char *display, BayonneSession *parent = NULL);
+		const char *name, const char *caller, const char *display, 
+		BayonneSession *parent = NULL, const char *manager = NULL);
 
 	/**
 	 * Returns a session pointer for a string identifier.  This can
@@ -2347,7 +2352,7 @@ protected:
 
 	virtual void dropCall(BayonneSession *child);
 
-	virtual Name *getIncoming(BayonneSession *s);
+	virtual Name *getIncoming(ScriptImage *img, BayonneSession *s, Event *event);
 
 public:
 	static const char *submitRequest(const char **data);
@@ -2573,6 +2578,12 @@ public:
 	inline bool isPeering(void)
 		{return state.peering;};
 
+	inline BayonneSpan *getSpan(void)
+		{return span;};
+
+	inline timeslot_t getTimeslot(void)
+		{return timeslot;};
+
 	/**
 	 * Process interpreter session symbols.
 	 *
@@ -2761,6 +2772,8 @@ public:
 	 */
 	virtual ~BayonneSession();
 
+	const char *getDigits(void);
+
 	inline const char *defVoicelib(void)
 		{return voicelib;}
 
@@ -2975,6 +2988,13 @@ public:
 	 */
 	bool isAssociated(void);
 
+	/**
+ 	 * Set new call association.  Used by ACD.
+	 *
+	 * @param session to associate with.
+	 */
+	void associate(BayonneSession *s);
+
 	inline bool isHolding(void)
 		{return holding;};
 
