@@ -28,9 +28,32 @@ ScriptBinder(id)
 		binder = this;
 }
 
-Script::Name *BayonneBinder::getIncoming(BayonneSession *s)
+Script::Name *BayonneBinder::getIncoming(ScriptImage *img, BayonneSession *s, Event *event)
 {
-	return NULL;
+	BayonneSpan *span = s->getSpan();
+	Name *scr;
+	char buf[65];
+
+	if(sla[0])
+	{
+		scr = img->getScript(sla);
+		if(scr)
+			return scr;
+	}
+
+	if(s->getInterface() == IF_INET)	
+		return NULL;
+
+	if(span)
+	{
+		snprintf(buf, sizeof(buf), "timeslot::span%d", span->getId());
+		scr = img->getScript(buf);
+		if(scr)
+			return scr;
+	}
+
+	snprintf(buf, sizeof(buf), "timeslot::%d", s->getTimeslot());
+	return img->getScript(buf);
 }
 
 BayonneSession *BayonneBinder::session(ScriptInterp *s)
