@@ -192,7 +192,7 @@ void BayonneSysexec::run(void)
 				kill(pid, SIGINT);
 			}
 			else
-				slog.debug("libexec started; pid=%d, tsid=%s", pid, tsid);
+				SLOG_DEBUG("libexec started; pid=%d, tsid=%s", pid, tsid);
 		}
 		else if(!stricmp(cmd, "hangup"))
 			s->sysHangup(tsid);
@@ -271,7 +271,7 @@ var:
                         if(!s->postEvent(&event))
 				slog.error("libexec unknown transaction; tsid=%s", tsid);
                         else
-                                slog.debug("libexec %s; tsid=%s", cmd, tsid);
+                                SLOG_DEBUG("libexec %s; tsid=%s", cmd, tsid);
                 }
 		else if(!stricmp(cmd, "exit"))
 			s->sysExit(tsid, tok);
