@@ -246,6 +246,14 @@ void BayonneSession::finalize(void)
 	SLOG_DEBUG("%s: session stopping", logname);
 }
 
+const char *BayonneSession::getDigits(void)
+{
+	if(!dtmf_digits)
+		return "";
+
+	return dtmf_digits;
+}
+
 const char *BayonneSession::getWritepath(char *buf, size_t len)
 {
 	char nbuf[128];
@@ -301,6 +309,16 @@ bool BayonneSession::isRefer(void)
         return false;
 }
 
+void BayonneSession::associate(BayonneSession *s)
+{
+	if(isAssociated())
+		exitCall("new association");
+
+	time(&time_joined);
+	strcpy(var_pid, s->var_sid);
+	enterCall();
+}
+
 bool BayonneSession::isAssociated(void)
 {
 	if(time_joined)
@@ -1083,7 +1101,6 @@ Script::Name *BayonneSession::attachStart(Event *event)
 	bool ref = false;
 	unsigned pri = 0;
 	Line *line;
-	char buf[65];
 	struct tm *dt, dtr;
 	const char *cp;
 
@@ -1108,79 +1125,15 @@ Script::Name *BayonneSession::attachStart(Event *event)
 		goto final;
 	}
 
-	scr = BayonneBinder::binder->getIncoming(this);
-	if(scr)
+	scr = BayonneBinder::binder->getIncoming(img, this, event);
+	if(scr && scr->first )
 		goto final;
 
-	if(sla[0])
-	{
-		scr = img->getScript(sla);
-		if(scr)
-			goto final;
-	}
-
-	cid = getSymbol("session.caller");
-	if(cid)
-	{
-		snprintf(buf, sizeof(buf), "caller::%s", cid);
-		scr = img->getScript(buf);
-		if(scr)
-			goto final;
-	}
-
-	did = getSymbol("session.dialed");
-	if(did && cid && !stricmp(did, cid))
-	{
-		scr = img->getScript("dialed::_self_");
-		if(scr)
-			goto final;
-	}
-
-	if(did)
-	{
-		snprintf(buf, sizeof(buf), "dialed::%s", did);
-		scr = img->getScript(buf);
-		if(scr)
-			goto final;
-	}
-
 	scr = event->start.scr;
-	if(scr)
-		goto final;
 
-	if(iface == IF_INET)
-		goto incoming;
+	if(scr && scr->first)
+		goto final;		
 
-	snprintf(buf, sizeof(buf), "timeslot::%s%d",
-		driver->getName(), timeslot - driver->getFirst());
-	scr = img->getScript(buf);
-	if(scr)
-		goto final;
-	
-	snprintf(buf, sizeof(buf), "timeslot::port%d", timeslot);
-	scr = img->getScript(buf);
-	if(scr)
-		goto final;
-
-	if(span)
-	{
-		snprintf(buf, sizeof(buf), "timeslot::span%d-%d", 
-			span->id, timeslot - span->getFirst());
-		scr = img->getScript(buf);
-		if(scr)
-			goto final;
-
-		snprintf(buf, sizeof(buf), "timeslot::span%d", span->id);
-		scr = img->getScript(buf);
-		if(scr)
-			goto final;
-	}
-
-	scr = img->getScript("timeslot::default");
-	if(scr)
-		goto final;
-
-incoming:
 	id = server->getLast("startup");
 	if(id)
 	{
