@@ -622,12 +622,11 @@ void Session::run(void)
 				}
 
 				session = Bayonne::startDialing(argv[1], 
-					argv[2], argv[3], argv[4]);
+					argv[2], argv[3], argv[4], NULL, "tcpmon");
 				if(!session)
 					*tcp() << "*** session unable to start call" << endl;
 				else
 				{
-					session->setConst("session.manager", "tcpmon");
 					*tcp() << "starting call " << session->getExternal("session.id") << endl;
 					session->leave();
 				}
