@@ -310,10 +310,9 @@ void Session::htmlControl(void)
 			errmsg = "destination missing";
 			goto results;
 		}
-		s = Bayonne::startDialing(qtarget, qscript, qcaller, qdisplay);
+		s = Bayonne::startDialing(qtarget, qscript, qcaller, qdisplay, NULL, "webservice");
 		if(s)
 		{
-			s->setConst("session.manager", "webservice");
 			sid = s->getExternal("session.id");
 			success = true;
 			s->leave();
