@@ -61,6 +61,22 @@ const char *Checks::chkPaths(Line *line, ScriptImage *img)
 	return NULL;
 }
 
+const char *Checks::chkTrap(Line *line, ScriptImage *img)
+{
+	unsigned idx = 0;
+
+	if(getMember(line))
+		return "trap uses no members";
+
+	if(!useKeywords(line, "=id=text"))
+		return "invalid keyword, use id and text";
+
+	if(getOption(line, &idx))
+		return "no options are passed for trap";	
+
+	return NULL;
+}
+
 const char *Checks::chkChildSignal(Line *line, ScriptImage *img)
 {
 	unsigned idx = 0;
