@@ -240,13 +240,6 @@ void liveConfig(void)
 		cfgid = NULL;
 
 #endif
-	if(cfgid)
-	{
-		snprintf(path, sizeof(path), "%s-%s", CONFIG_FILES, cfgid);
-		keypaths.setValue("config", path);
-		snprintf(path, sizeof(path), "%s-%s", RUN_FILES, cfgid);
-		keypaths.setValue("runfiles", path);
-	}
         sp = (char *)keyserver.getLast("definitions");
 
 	if(sp && !stricmp(sp, "default"))
@@ -451,6 +444,17 @@ void liveConfig(void)
 
 void loadConfig(void)
 {
+	const char *cfgid = Process::getEnv("BAYONNE_CONFIG");
+	char path[128];
+
+    if(cfgid)
+    {
+        snprintf(path, sizeof(path), "%s-%s", CONFIG_FILES, cfgid);
+        keypaths.setValue("config", path);
+        snprintf(path, sizeof(path), "%s-%s", RUN_FILES, cfgid);
+        keypaths.setValue("runfiles", path);
+    }
+
 #ifdef	WIN32
 	char pbuf[256];
 	const char *config = keypaths.getLast("config");
