@@ -1508,16 +1508,20 @@ bool Methods::scrEcho(void)
 	FILE *fp = fopen(server->getLast("output"), "a");
 	serialize.enter();
 
-	while(NULL != (val = getValue(NULL)))
+	if(fp)
 	{
-		fputs(val, fp);
-		cout << val;
-	}
+		while(NULL != (val = getValue(NULL)))
+		{
+			fputs(val, fp);
+			cout << val;
+		}
 	
-	fputc('\n', fp);
+		fputc('\n', fp);
+	}
 	cout << endl;
 	serialize.leave();
-	fclose(fp);
+	if(fp)
+		fclose(fp);
 	advance();
 	return true;
 }
