@@ -194,6 +194,9 @@ ScriptRuntime()
 	ScriptInterp::addConditional("voice", &testVoice);
 	ScriptInterp::addConditional("lang", &testLang);
 	ScriptInterp::addConditional("language", &testLang);
+	ScriptInterp::addConditional("pattern", &testPattern);
+	ScriptInterp::addConditional("dialed", &testDialed);
+    ScriptInterp::addConditional("caller", &testCaller);
 }
 
 unsigned long Runtime::getTrapMask(const char *trapname)
@@ -456,6 +459,33 @@ bool Runtime::testTimeslot(ScriptInterp *interp, const char *v)
 	return false;
 }
 
+bool Runtime::testDialed(ScriptInterp *interp, const char *v)
+{
+	const char *did = getRegistryId(interp->getSymbol("session.dialed"));
+
+	if(!did)
+		return false;
+
+	return matchDigits(did, v, false);
+}
+
+bool Runtime::testCaller(ScriptInterp *interp, const char *v)
+{
+    const char *cid = getRegistryId(interp->getSymbol("session.caller"));
+
+    if(!cid)
+        return false;
+
+    return matchDigits(cid, v, false);
+}
+
+bool Runtime::testPattern(ScriptInterp *interp, const char *v)
+{
+	BayonneSession *s = (BayonneSession *)(interp);
+
+	return matchDigits(s->getDigits(), v, false);
+} 
+
 bool Runtime::testVoice(ScriptInterp *interp, const char *v)
 {
 	BayonneSession *s = (BayonneSession *)(interp);
@@ -552,10 +582,9 @@ bool Runtime::command(char *cmd)
 
 		caller = strtok_r(NULL, " \t\r\n", &tok);
 		display = strtok_r(NULL, " \t\r\n", &tok);
-		s = startDialing(dial, cmd, caller, display);
+		s = startDialing(dial, cmd, caller, display, NULL, "server");
 		if(!s)
 			return false;
-		s->setConst("session.manager", "server");
 		s->leave();
 		return true;
 	}	
@@ -727,6 +756,11 @@ void Runtime::process(void)
 	mkfifo(buf, 0770);
 	fifo = ::open(buf, O_RDWR);
 	keypaths.setValue("runfifo", buf);
+	if(fifo < 0)
+	{
+		Bayonne::errlog("error", "cannot open control fifo %s", buf);
+		Thread::sleep(TIMEOUT_INF);
+	}
 	for(;;)
 	{
 		readline(buf, sizeof(buf));
