@@ -199,6 +199,9 @@ protected:
 	static bool testVoice(ScriptInterp *interp, const char *v);
 	static bool testLang(ScriptInterp *interp, const char *v);
 	static bool testLevel(ScriptInterp *interp, const char *v);
+	static bool testPattern(ScriptInterp *interp, const char *v);
+	static bool testDialed(ScriptInterp *interp, const char *v);
+    static bool testCaller(ScriptInterp *interp, const char *v);
 
 public:
 	static void process(void);
